@@ -2,20 +2,6 @@
 
 import sys
 import click
-from uparse_python import die
-
-# Prefix = ""
-# if len(sys.argv) > 2:
-# 	Prefix = sys.argv[2]
-#
-# NeedSize = 0
-# if len(sys.argv) > 3:
-# 	if sys.argv[3] == "-needsize":
-# 		NeedSize = 1
-# 	elif sys.argv[3] == "-nosize":
-# 		NeedSize = 0
-# 	else:
-# 		die.Die("Must specify -needsize or -nosize")
 
 def GetSize(Label):
 	Fields = Label.split(";")
@@ -27,7 +13,7 @@ def GetSize(Label):
 	sys.exit(1)
 
 @click.command()
-@click.option('--fasta', type=click.File('r'), prompt=True,help="name of the FASTA file to renumber")
+@click.option('--fasta', type=click.Path(exists=True), prompt=True,help="name of the FASTA file to renumber")
 @click.option('--prefix', type=click.STRING, default="OTU_",help="string prefix")
 @click.option('--needsize/--no-needsize', default=False, help="add a size suffix")
 def fasta_number(fasta, prefix, needsize):
@@ -35,7 +21,7 @@ def fasta_number(fasta, prefix, needsize):
 	see: http://drive5.com/python/fasta_number_py.html
 	"""
 
-	File = open(fasta)
+	File = open(fasta,'r')
 	N = 0
 	while 1:
 		Line = File.readline()
@@ -46,11 +32,11 @@ def fasta_number(fasta, prefix, needsize):
 			continue
 		if Line[0] == '>':
 			N += 1
-			if NeedSize:
+			if needsize:
 				Label = Line[1:].strip()
 				Size = GetSize(Label)
-				print ">%s%u;size=%u;" % (Prefix, N, Size)
+				print ">%s%u;size=%u;" % (prefix, N, Size)
 			else:
-				print ">%s%u" % (Prefix, N)
+				print ">%s%u" % (prefix, N)
 		else:
 			print Line
\ No newline at end of file
